import { Route, Switch } from "wouter";
import { QueryClientProvider } from "@tanstack/react-query";
import { Suspense, lazy } from "react";
import { queryClient } from "./lib/queryClient";
import { Toaster } from "@/components/ui/toaster";
import { TooltipProvider } from "@/components/ui/tooltip";
import { HelmetProvider } from "react-helmet-async";
import { CookiesProvider } from 'react-cookie';
import { LocationProvider } from "@/hooks/useLocation";
import { AuthProvider } from "@/hooks/use-auth";
import { ProtectedRoute } from "@/lib/protected-route";
import OrganizationStructuredData from "@/components/OrganizationStructuredData";
import DesktopWhatsAppButton from "@/components/DesktopWhatsAppButton";
import { SkipNavigation } from "@/components/AccessibilityEnhancements";

// Critical pages - loaded immediately with preloading optimization
import NotFound from "@/pages/not-found";
import Home from "@/pages/Home";

// High-priority pages - lazy loaded with preloading
const WorkspacesPage = lazy(() => import("@/pages/WorkspacesPage"));
const WorkspacePage = lazy(() => import("@/pages/WorkspacePage"));

// Non-critical pages - lazy loaded
const LocationPage = lazy(() => import("@/pages/LocationPage"));
const AwfisPartnership = lazy(() => import("@/pages/AwfisPartnership"));
const AboutPage = lazy(() => import("@/pages/AboutPage"));
const ContactPage = lazy(() => import("@/pages/ContactPage"));
const ThankYouPage = lazy(() => import("@/pages/ThankYouPage"));
const PaymentSuccessPage = lazy(() => import("@/pages/PaymentSuccessPage"));
const Admin = lazy(() => import("@/pages/Admin"));
const BlogPage = lazy(() => import("@/pages/BlogPage"));
const BlogPostPage = lazy(() => import("@/pages/BlogPostPage"));
const AuthPage = lazy(() => import("@/pages/auth-page"));
const PrivacyPolicyPage = lazy(() => import("@/pages/PrivacyPolicyPage"));
const TermsOfServicePage = lazy(() => import("@/pages/TermsOfServicePage"));
const SitemapPage = lazy(() => import("@/pages/SitemapPage"));
const VirtualOfficeBenefitsPage = lazy(() => import("@/pages/VirtualOfficeBenefitsPage"));
const AffordablePlansPage = lazy(() => import("@/pages/AffordablePlansPage"));
const RemoteWorkSolutionsPage = lazy(() => import("@/pages/RemoteWorkSolutionsPage"));
const StartupsPage = lazy(() => import("@/pages/StartupsPage"));
const EnterpriseSolutionsPage = lazy(() => import("@/pages/EnterpriseSolutionsPage"));
const CalculatorsPage = lazy(() => import("@/pages/CalculatorsPage"));
const StartupCostCalculatorPage = lazy(() => import("@/pages/StartupCostCalculatorPage"));
const VirtualOfficeROICalculatorPage = lazy(() => import("@/pages/VirtualOfficeROICalculatorPage"));
const BusinessSavingsCalculatorPage = lazy(() => import("@/pages/BusinessSavingsCalculatorPage"));
const DynamicRouter = lazy(() => import("@/components/DynamicRouter"));

// Optimized loading component for lazy-loaded pages
const PageLoader = () => (
  <div className="min-h-screen flex items-center justify-center above-fold">
    <div className="loading-skeleton rounded-full h-8 w-8"></div>
  </div>
);

function App() {
  return (
    <HelmetProvider>
      <QueryClientProvider client={queryClient}>
        <AuthProvider>
          <CookiesProvider>
            <TooltipProvider>
              <SkipNavigation />
              <Toaster />
              <OrganizationStructuredData />
              <DesktopWhatsAppButton />
              <LocationProvider>
                <Switch>
                {/* Home Route */}
                <Route path="/" component={Home} />
                
                {/* Admin Routes */}
                <Route path="/admin/auth">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <AuthPage />
                    </Suspense>
                  )}
                </Route>
                <ProtectedRoute 
                  path="/admin" 
                  component={() => (
                    <Suspense fallback={<PageLoader />}>
                      <Admin />
                    </Suspense>
                  )}
                />
                
                {/* Blog Routes - must come before the dynamic location routes */}
                <Route path="/blog/:slug">
                  {params => (
                    <Suspense fallback={<PageLoader />}>
                      <BlogPostPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/blog">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <BlogPage />
                    </Suspense>
                  )}
                </Route>
                
                {/* Virtual Office Routes - Base route */}
                <Route path="/virtual-office">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <WorkspacesPage />
                    </Suspense>
                  )}
                </Route>
                
                {/* Individual workspaces with virtual-office prefix */}
                <Route path="/virtual-office/:slug">
                  {params => {
                    // Skip if this matches a predefined route to avoid conflicts
                    if (["blog", "admin", "workspaces", "about", "contact", "thank-you-1", "pages", "privacy-policy", "terms-of-service", "sitemap"].includes(params.slug)) {
                      return <NotFound />;
                    }
                    
                    // Check for workspace slugs with hyphenated names like "awfis-fun-republic"
                    // If slug contains a hyphen, treat it as a workspace first
                    if (params.slug.includes('-')) {
                      console.log("Attempting to load as workspace:", params.slug);
                      return (
                        <Suspense fallback={<PageLoader />}>
                          <WorkspacePage />
                        </Suspense>
                      );
                    }
                    
                    // Otherwise, treat it as a city
                    console.log("Loading as city:", params.slug);
                    return (
                      <Suspense fallback={<PageLoader />}>
                        <WorkspacesPage citySlug={params.slug} />
                      </Suspense>
                    );
                  }}
                </Route>
                
                {/* Individual workspaces with virtual-office-space prefix (for backward compatibility) */}
                <Route path="/virtual-office-space/:slug">
                  {params => (
                    <Suspense fallback={<PageLoader />}>
                      <WorkspacePage />
                    </Suspense>
                  )}
                </Route>
                
                {/* City-specific Virtual Office Routes - Legacy format (kept for backward compatibility) */}
                <Route path="/:city/virtual-office">
                  {(params) => {
                    // Skip if this is an admin or other predefined route to avoid conflicts
                    if (["blog", "admin", "workspaces", "virtual-office", "about", "contact", "thank-you-1", "pages", "privacy-policy", "terms-of-service", "sitemap"].includes(params.city)) {
                      return <NotFound />;
                    }
                    return (
                      <Suspense fallback={<PageLoader />}>
                        <WorkspacesPage citySlug={params.city} />
                      </Suspense>
                    );
                  }}
                </Route>
                
                {/* Workspace Routes - Legacy routes kept for backward compatibility and SEO preservation */}
                <Route path="/workspaces/:slug">
                  {params => (
                    <Suspense fallback={<PageLoader />}>
                      <WorkspacePage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/workspaces">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <WorkspacesPage />
                    </Suspense>
                  )}
                </Route>
                
                {/* Public Routes */}
                <Route path="/about">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <AboutPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/contact">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <ContactPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/thank-you-1">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <ThankYouPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/pages/thank-you-1">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <ThankYouPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/payment-success">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <PaymentSuccessPage />
                    </Suspense>
                  )}
                </Route>
                {/* Legal Pages */}
                <Route path="/privacy-policy">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <PrivacyPolicyPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/terms-of-service">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <TermsOfServicePage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/sitemap">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <SitemapPage />
                    </Suspense>
                  )}
                </Route>
                {/* Partnership page */}
                <Route path="/partnership/awfis">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <AwfisPartnership />
                    </Suspense>
                  )}
                </Route>
                {/* Service Pages */}
                <Route path="/benefits">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <VirtualOfficeBenefitsPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/affordable-plans">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <AffordablePlansPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/remote-work-solutions">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <RemoteWorkSolutionsPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/startups">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <StartupsPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/enterprise-solutions">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <EnterpriseSolutionsPage />
                    </Suspense>
                  )}
                </Route>
                
                {/* Calculator Routes */}
                <Route path="/calculators">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <CalculatorsPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/calculators/startup-cost">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <StartupCostCalculatorPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/calculators/roi">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <VirtualOfficeROICalculatorPage />
                    </Suspense>
                  )}
                </Route>
                <Route path="/calculators/savings">
                  {() => (
                    <Suspense fallback={<PageLoader />}>
                      <BusinessSavingsCalculatorPage />
                    </Suspense>
                  )}
                </Route>
                {/* Area pages route - New format: virtual-office/location/area */}
                <Route path="/virtual-office/:location/:area">
                  {params => {
                    // Skip if path starts with predefined routes to avoid conflict
                    if (["blog", "admin", "workspaces", "about", "contact", "thank-you-1", "pages", "privacy-policy", "terms-of-service", "sitemap"].includes(params.location)) return <NotFound />;
                    return (
                      <Suspense fallback={<PageLoader />}>
                        <LocationPage areaSlug={params.area} />
                      </Suspense>
                    );
                  }}
                </Route>
                
                {/* Area pages route - Legacy format (kept for backward compatibility) */}
                <Route path="/:location/:area">
                  {params => {
                    // Skip if path starts with predefined routes to avoid conflict
                    if (["blog", "admin", "workspaces", "virtual-office", "about", "contact", "thank-you-1", "pages", "privacy-policy", "terms-of-service", "sitemap"].includes(params.location)) return <NotFound />;
                    return (
                      <Suspense fallback={<PageLoader />}>
                        <LocationPage areaSlug={params.area} />
                      </Suspense>
                    );
                  }}
                </Route>
                {/* Workspace slug check before location routes */}
                <Route path="/:slug">
                  {params => {
                    // Skip if path starts with predefined routes to avoid conflict
                    if (["blog", "admin", "workspaces", "virtual-office", "about", "contact", "thank-you-1", "pages", "privacy-policy", "terms-of-service", "sitemap"].includes(params.slug)) return <NotFound />;
                    
                    // We need to check if this is a workspace slug or a location slug
                    return (
                      <Suspense fallback={<PageLoader />}>
                        <DynamicRouter slug={params.slug} />
                      </Suspense>
                    );
                  }}
                </Route>
                
                {/* Fallback */}
                <Route component={NotFound} />
              </Switch>
            </LocationProvider>
          </TooltipProvider>
        </CookiesProvider>
      </AuthProvider>
    </QueryClientProvider>
  </HelmetProvider>
);
}

export default App;
